@@ -73,9 +73,6 @@ enum Command {
         name: v1::StateName,
     },
 
-    #[structopt(about = "List registered clusters", aliases = &["list-cluster", "list-cl", "lc"], display_order(10))]
-    ListClusters,
-
     #[structopt(about = "Register new cluster", aliases = &["register-cl", "rc"], display_order(10))]
     RegisterCluster {
         #[structopt(help = "Cluster name, defaults to current k8s context")]
@@ -127,7 +124,7 @@ enum Command {
         provider: Option<v1::Provider>,
     },
 
-    #[structopt(about = "Unregister existing cluster", aliases = &["unregister-cl", "uc"], display_order(10))]
+    #[structopt(about = "Unregister existing cluster", aliases = &["unregister-cl", "uc"], display_order(11))]
     UnregisterCluster {
         #[structopt(help = "Skip confirmation", long, short)]
         force: bool,
@@ -135,7 +132,10 @@ enum Command {
         name: v1::ClusterName,
     },
 
-    #[structopt(about = "Show registered cluster details", aliases = &["show-cl", "sc"], display_order(10))]
+    #[structopt(about = "List registered clusters", aliases = &["list-cluster", "list-cl", "lc"], display_order(12))]
+    ListClusters,
+
+    #[structopt(about = "Show registered cluster details", aliases = &["show-cl", "sc"], display_order(13))]
     ShowCluster {
         #[structopt(help = "Cluster name")]
         name: Option<v1::ClusterName>,
@@ -184,7 +184,7 @@ enum Command {
         cluster: v1::ClusterName,
     },
 
-    #[structopt(about = "Manually create new volume", display_order(50))]
+    #[structopt(about = "Manually create new volume", aliases = &["create-v", "cv"], display_order(50))]
     CreateVolume {
         #[structopt(help = "State name")]
         state: v1::StateName,
@@ -196,7 +196,7 @@ enum Command {
         fs_type: v1::VolumeFileSystem,
     },
 
-    #[structopt(about = "Manually delete existing volume", display_order(50))]
+    #[structopt(about = "Manually delete existing volume", aliases = &["delete-v", "dv"], display_order(50))]
     DeleteVolume {
         #[structopt(help = "State name")]
         state: v1::StateName,
@@ -204,6 +204,30 @@ enum Command {
         volume: v1::VolumeName,
     },
 
+    #[structopt(
+        about = "Manually choose primary location for volume",
+        aliases = &["set-v", "sv"],
+        display_order(50)
+    )]
+    SetVolume {
+        #[structopt(help = "State name")]
+        state: v1::StateName,
+        #[structopt(help = "Volume name")]
+        volume: v1::VolumeName,
+        #[structopt(help = "Primary location specification", long, short)]
+        primary: Location,
+    },
+
+    #[structopt(
+        about = "List volumes in the given state",
+        aliases = &["list-volume", "list-v", "lv"],
+        display_order(50)
+    )]
+    ListVolumes {
+        #[structopt(help = "State name")]
+        state: v1::StateName,
+    },
+
     #[structopt(
         about = "Create new namespace",
         aliases = &["cns", "c-ns", "create-ns"],
@@ -312,7 +336,6 @@ impl Cli {
             Command::DeleteState { name: state } => statehub.delete_state(state).await,
             Command::ListStates => statehub.list_states().await,
             Command::ShowState { name } => statehub.show_state(&name).await,
-            Command::ListClusters => statehub.list_clusters().await,
             Command::RegisterCluster {
                 name,
                 states,
@@ -351,6 +374,7 @@ impl Cli {
             Command::UnregisterCluster { force, name } => {
                 statehub.unregister_cluster(name, force).await
             }
+            Command::ListClusters => statehub.list_clusters().await,
             Command::ShowCluster { name } => {
                 let name = name.or_else(k8s::get_cluster_name).ok_or_else(|| {
                     anyhow::anyhow!(
@@ -375,6 +399,12 @@ impl Cli {
                 fs_type,
             } => statehub.create_volume(state, volume, size, fs_type).await,
             Command::DeleteVolume { state, volume } => statehub.delete_volume(state, volume).await,
+            Command::SetVolume {
+                state,
+                volume,
+                primary,
+            } => statehub.set_volume_primary(state, volume, primary).await,
+            Command::ListVolumes { state } => statehub.list_volumes(state).await,
             Command::CreateNamespace { namespace } => statehub.create_namespace(namespace).await,
             Command::SaveClusterToken { namespace, token } => {
                 statehub.save_cluster_token(namespace, token).await
@@ -597,6 +627,22 @@ impl StateHub {
             .handle_output(self.json)
     }
 
+    async fn set_volume_primary(
+        &self,
+        state: v1::StateName,
+        volume: v1::VolumeName,
+        primary: Location,
+    ) -> anyhow::Result<()> {
+        self.api
+            .set_volume_primary(state, volume, primary)
+            .await
+            .handle_output(self.json)
+    }
+
+    async fn list_volumes(&self, state: v1::StateName) -> anyhow::Result<()> {
+        self.api.list_volumes(state).await.handle_output(self.json)
+    }
+
     pub(crate) async fn set_availability(self) -> anyhow::Result<()> {
         // Ok(Output::<String>::todo()).handle_output(self.json)
         anyhow::bail!(self.show(Output::<String>::todo()))
